==> jbossas-plugin-1.3-sources.jar: com/xebialabs/deployit/plugin/jbossas/mapper/EjbJarToJbossasServerMapper.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.jbossas.mapper;

import java.util.List;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.ci.artifact.EjbJar;
import com.xebialabs.deployit.mapper.MappingAgnosticStepGeneratingMapper;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasEjbJarMapping;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer;
import com.xebialabs.deployit.plugin.jbossas.step.JbossasDeployApplicationStep;
import com.xebialabs.deployit.plugin.jbossas.step.JbossasUndeployApplicationStep;

public class EjbJarToJbossasServerMapper extends MappingAgnosticStepGeneratingMapper<EjbJar, JbossasEjbJarMapping, JbossasServer> {

	public EjbJarToJbossasServerMapper(Change<Deployment> change) {
		super(change);
	}

	@Override
	protected void generateAdditionStepsForAddedMapping(EjbJar newSource, JbossasServer newTarget, List<Step> steps) {
		steps.add(new JbossasDeployApplicationStep(newTarget, newSource));
	}

	@Override
	protected void generateDeletionStepsForDeletedMapping(EjbJar oldSource, JbossasServer oldTarget, List<Step> steps) {
		steps.add(new JbossasUndeployApplicationStep(oldTarget, oldSource));
	}

}

==> jbossas-plugin-1.4-sources.jar: com/xebialabs/deployit/plugin/jbossas/mapper/EjbJarToJbossasServerMapper.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.jbossas.mapper;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.ci.artifact.EjbJar;
import com.xebialabs.deployit.mapper.StepGeneratingMapper;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasEjbJarMapping;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer;
import com.xebialabs.deployit.plugin.jbossas.step.JbossasDeployApplicationStep;
import com.xebialabs.deployit.plugin.jbossas.step.JbossasUndeployApplicationStep;

import java.util.List;

public class EjbJarToJbossasServerMapper extends StepGeneratingMapper<EjbJar, JbossasEjbJarMapping, JbossasServer> {

	public EjbJarToJbossasServerMapper(Change<Deployment> change) {
		super(change);
	}

	@Override
	protected void generateAdditionStepsForAddedMapping(EjbJar newMappingSource, JbossasEjbJarMapping newMapping, JbossasServer newMappingTarget, List<Step> steps) {
		steps.add(new JbossasDeployApplicationStep(newMappingTarget, newMappingSource, newMapping));
	}

	@Override
	protected void generateDeletionStepsForDeletedMapping(EjbJar oldMappingSource, JbossasEjbJarMapping oldVersionOfModifiedMapping, JbossasServer oldMappingTarget, List<Step> steps) {
		steps.add(new JbossasUndeployApplicationStep(oldMappingTarget, oldMappingSource, oldVersionOfModifiedMapping));
	}

}
